@@ -1,6 +1,8 @@
 from selenium import webdriver
 from selenium.webdriver.firefox.options import Options
 from selenium.common.exceptions import NoAlertPresentException,TimeoutException,NoSuchElementException,WebDriverException,ElementNotVisibleException
+from tkinter import ttk,Tk,Label,Entry
+import tkinter as tk
 import os
 import time
 import shutil
@@ -10,6 +12,100 @@ import shaonutil
 import pipreqs
 
 
+package_name = ''
+
+def make_package_config():
+    package_name = ''
+    version = ''
+    author_name = ''
+    keywords = ''
+    console_decision = ''
+    github_user = ''
+    github_pass = ''
+    github_project_url = ''
+    pypi_user = ''
+    pypi_pass = ''
+
+    window = Tk()
+    window.title("Welcome to Package Config")
+    window.geometry('400x400')
+    window.configure(background = "grey");
+
+    package_name_ = tk.StringVar(window)
+    version_ = tk.StringVar(window)
+    author_name_ = tk.StringVar(window)
+    keywords_ = tk.StringVar(window)
+    console_decision_ = tk.StringVar(window)
+    github_user_ = tk.StringVar(window)
+    github_pass_ = tk.StringVar(window)
+    github_project_url_ = tk.StringVar(window)
+    pypi_user_ = tk.StringVar(window)        
+    pypi_pass_ = tk.StringVar(window)
+
+
+
+    Label(window ,text = "Package Config").grid(row = 0,column = 0,columnspan=2)
+    Label(window ,text = "Package Name").grid(row = 1,column = 0)
+    Label(window ,text = "Version").grid(row = 2,column = 0)
+    Label(window ,text = "Author Name").grid(row = 3,column = 0)
+    Label(window ,text = "Keywords").grid(row = 4,column = 0)
+    Label(window ,text = "Console Decision").grid(row = 5,column = 0)
+    Label(window ,text = "Github User").grid(row = 6,column = 0)
+    Label(window ,text = "Github Password").grid(row = 7,column = 0)
+    Label(window ,text = "Github Project Url").grid(row = 8,column = 0)
+    Label(window ,text = "PyPi User").grid(row = 9,column = 0)
+    Label(window ,text = "PyPi Password").grid(row = 10,column = 0)
+
+    Entry(window,textvariable=package_name_).grid(row = 1,column = 1)        
+    Entry(window,textvariable=version_).grid(row = 2,column = 1)        
+    Entry(window,textvariable=author_name_).grid(row = 3,column = 1)
+    Entry(window,textvariable=keywords_).grid(row = 4,column = 1)
+    Entry(window,textvariable=console_decision_).grid(row = 5,column = 1)
+    Entry(window,textvariable=github_user_).grid(row = 6,column = 1)        
+    Entry(window,show="*",textvariable=github_pass_).grid(row = 7,column = 1)
+    Entry(window,textvariable=github_project_url_).grid(row = 8,column = 1)
+    Entry(window,textvariable=pypi_user_).grid(row = 9,column = 1)
+    Entry(window,textvariable=pypi_pass_).grid(row = 10,column = 1)
+
+    def clicked():
+        package_nameT = package_name_.get()
+        version = version_.get()
+        author_name = author_name_.get()
+        keywords = keywords_.get()
+        console_decision = console_decision_.get()
+        github_user = github_user_.get()
+        github_pass = github_pass_.get()
+        github_project_url = github_project_url_.get()
+        pypi_user = pypi_user_.get()
+        pypi_pass = pypi_pass_.get()
+
+        
+
+        strs = f"""; github config
+[PACKAGE]
+package_name = {package_nameT}
+version = {version}
+author_name = {author_name}
+keywords = {keywords}
+console_decision = {console_decision}
+github_project_url = {github_project_url}
+github_user = {github_user}
+github_pass = {github_pass}
+pypi_user = {pypi_user}
+pypi_pass = {pypi_pass}"""
+
+        shaonutil.file.write_file("private/package.config",strs)
+
+
+        window.destroy()
+
+    btn = ttk.Button(window ,text="Submit",command=clicked).grid(row=11,column=0)
+    window.mainloop()
+
+    config = shaonutil.file.read_configuration_ini("private/package.config")
+    package_name = config['PACKAGE']['package_name']
+
+
 def get_package_name():
     vname = ''
     lines = shaonutil.file.read_file('setup.py')
@@ -24,12 +120,12 @@ def get_package_name():
                 vname = s[start:end]
                 break
             i+=1
-    else:
-        vname = input("Give Package Name : ")
+    if vname == '':
+        vname = input("Enter Package Name : ")
+
     return vname
 
 
-package_name = get_package_name()
 
 def initialize_git(project_github_url=''):
     if project_github_url == '':
@@ -45,27 +141,17 @@ git push -u origin master"""
         for path in execute_shell(command):
             print(path, end="")
 
+
 def create_setup_py():
     config = shaonutil.file.read_configuration_ini('private/package.config')
-    """
-    package_name = input("Enter package_name : ")
-    version = input("Enter version : ")
-    author = input("Enter author : ")
+    package_name = config['PACKAGE']['package_name']
+    version = config['PACKAGE']['version']
+    author_name = config['PACKAGE']['author_name']
     author_email = config['PACKAGE']['github_user']
-    project_url = input("Enter project_url : ")
-    config = shaonutil.file.read_configuration_ini('private/package.config')
+    project_url = config['PACKAGE']['github_project_url']
     project_github_url = config['PACKAGE']['github_project_url']
-    keywords = input("Enter keywords seperated by comma : ")
-    console_decision = input("Do u need console_scripts ? : ")
-    """
-    package_name = "PackageMaster"
-    version = "0.0.0.1.1"
-    author = "Shaon Majumder"
-    author_email = config['PACKAGE']['github_user']
-    project_url = "https://github.com/ShaonMajumder/PackageMaster"
-    project_github_url = config['PACKAGE']['github_project_url']
-    keywords = "Package Maker,PyPi Uploader,Shaon Majumder"
-    console_decision = "y"
+    keywords = config['PACKAGE']['keywords']
+    console_decision = config['PACKAGE']['console_decision']
 
     classifiers = []
     download_url = project_github_url+'/archive/'+version+'.tar.gz'
@@ -92,7 +178,7 @@ setup(
     version = '{version}',
     long_description=long_description,
     long_description_content_type='text/markdown',
-    author = '{author}',
+    author = '{author_name}',
     author_email = '{author_email}',
     url = '{project_url}',
     download_url = '{download_url}',
@@ -123,7 +209,7 @@ setup(
     version = '{version}',
     long_description=long_description,
     long_description_content_type='text/markdown',
-    author = '{author}',
+    author = '{author_name}',
     author_email = '{author_email}',
     url = '{project_url}',
     download_url = '{download_url}',
@@ -208,24 +294,13 @@ def changing_version_name_prev(new_vname):
     lines[i] = s
     strs = '\n'.join(lines)
     shaonutil.file.write_file('setup.py',strs)
-    
-def make_config():
-    """
-    package_name
-    initial_version
-    #0.0.0.0.1
-    author
-    author_email
-    git_project_url
-    download_url
-    keywords
-    """
-    pass
 
+def check_necessary_resources(package_name_=''):
+    if package_name_ == '':
+        package_name = get_package_name()
+    else:
+        package_name = package_name_
 
-
-
-def checks_folder(package_name):
     dirs = shaonutil.file.get_all_dirs()
     print("Checking the required files/folders ...")
     folders = f"""private/
@@ -249,21 +324,7 @@ LICENSE
             elif 'private/package.config' in folder:
                 input_ = input("Do u want to create package.config "+folder+" (y/n) : ")
                 if input_ == 'y' or input_ == 'Y':
-                    github_project_url = input("Enter Github Project url : ")
-                    github_user = input("Enter Github User : ")
-                    github_pass = input("Enter Github Password : ")
-                    pypi_user = input("Enter PyPi User : ")
-                    pypi_pass = input("Enter PyPi Password : ")
-
-                    strs = f"""; github config
-[PACKAGE]
-github_project_url = {github_project_url}
-github_user = {github_user}
-github_pass = {github_pass}
-pypi_user = {pypi_user}
-pypi_pass = {pypi_pass}"""
-
-                    shaonutil.file.write_file("private/package.config",strs)
+                    make_package_config()
             elif 'private/' in folder:
                 input_ = input("Do u want to create directory "+folder+" (y/n) : ")
                 if input_ == 'y' or input_ == 'Y':
@@ -293,7 +354,9 @@ pypi_pass = {pypi_pass}"""
             elif package_name in folder:
                 input_ = input("Do u want to create "+folder+" (y/n) : ")
                 if input_ == 'y' or input_ == 'Y':
+                    
                     os.mkdir(package_name)
+                    folders[3] = package_name + '/'
                     #moveall()
                     print(folders)
                     for dir_ in shaonutil.file.get_all_files_dirs():
@@ -310,7 +373,7 @@ pypi_pass = {pypi_pass}"""
                     
 
 
-def check_modules():
+def check_necessary_packages():
     print("Checking the required modules ...")
     modules = """setuptools
 wheel
@@ -351,9 +414,6 @@ git push -u origin master"""
         for path in execute_shell(command):
             print(path, end="")
 
-
-
-
 def make_release(release_tag,git_url,github_user,github_pass):
     git_url = git_url + '/releases/new'
     print("Making release ...")
@@ -398,17 +458,12 @@ def make_release(release_tag,git_url,github_user,github_pass):
         print('Release was not created.')
         return False
 
-    
-    
-
-
-    
 def upload_to_pypi(pypi_user,pypi_pass):
     
     if platform.system() == 'Linux':
-        commands = f"""twine upload dist/* -u {pypi_user} -p {pypi_pass}"""
+        commands = f"""twine upload dist/* -u {pypi_user} -p {pypi_pass} --verbose"""
     elif platform.system() == 'Windows':
-        commands = f"""twine upload dist/* -u {pypi_user} -p {pypi_pass}"""
+        commands = f"""twine upload dist/* -u {pypi_user} -p {pypi_pass} --verbose"""
 
     commands = commands.split("\n")
 
@@ -444,38 +499,34 @@ def locally_install():
             print(path, end="")
 
 def main():
-    check_modules()
-    checks_folder(package_name)
+    check_necessary_packages()
+    check_necessary_resources()
+
+    config_path = os.path.join(os.getcwd(),'private/package.config')
+    config = shaonutil.file.read_configuration_ini(config_path)
+    package_name = config['PACKAGE']['package_name']
+    git_url = config['PACKAGE']['github_project_url']
+    github_user = config['PACKAGE']['github_user']
+    github_pass = config['PACKAGE']['github_pass']
+    pypi_user = config['PACKAGE']['pypi_user']
+    pypi_pass = config['PACKAGE']['pypi_pass']
 
     pre_vname = get_version_name()
     print("Showing Previous Version :",pre_vname)
     new_vname = input("Give    New Version Name : ")
+    release_tag = input("Give New Release tag : ")
+
+    config['PACKAGE']['version'] = new_vname
+    shaonutil.file.write_configuration_ini(config,config_path)
 
     changing_version_name(pre_vname,new_vname)
-
     cleaning_before_commit(package_name)
-
     commit_push()
-    
-    config = shaonutil.file.read_configuration_ini('private/package.config')
-    git_url = config['PACKAGE']['github_project_url']
-    github_user = config['PACKAGE']['github_user']
-    github_pass = config['PACKAGE']['github_pass']
-    release_tag = input("Give New Release tag : ")
     make_release(release_tag,git_url,github_user,github_pass)
-
     ### git diff-index --quiet HEAD || git commit -m \""""+commit_msg+"""\";
-
     create_dist()
-
-    pypi_user = config['PACKAGE']['pypi_user']
-    pypi_pass = config['PACKAGE']['pypi_pass']
-    # pypi_user = input("Give pypi user : ")
-    # pypi_pass = input("Give pypi pass : ")
-    upload_to_pypi(pypi_user,pypi_pass)
-
     locally_install()
-
+    upload_to_pypi(pypi_user,pypi_pass)
     cleaning_before_commit(package_name)
 
 if __name__ == '__main__':
